@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2008 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.220 2012/08/13 22:23:35 robbat2 Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.225 2012/10/28 10:29:38 vapier Exp $
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2008 Mike Frysinger  - <vapier@gentoo.org>
@@ -40,7 +40,6 @@
 
 /* prototypes and such */
 static char eat_file(const char *file, char *buf, const size_t bufsize);
-int charmatch(const char *str1, const char *str2);
 int rematch(const char *, const char *, int);
 static char *rmspace(char *);
 
@@ -54,7 +53,6 @@ int lookup_applet_idx(const char *);
 /* variables to control runtime behavior */
 char *module_name = NULL;
 char *modpath = NULL;
-int found = 0;
 int verbose = 0;
 int quiet = 0;
 int portcachedir_type = 0;
@@ -249,24 +247,6 @@ static bool prompt(const char *p)
 	}
 }
 
-/* if all chars in str1 coincide with the begining of the str2 return 0 */
-int charmatch(const char *str1, const char *str2)
-{
-	if ((str1 == NULL) || (str2 == NULL))
-		return EXIT_FAILURE;
-
-	while (*str1 != 0) {
-		/* if str2==0 but str1!=0 we'll return and so it's
-		 * impossible to touch match++ address here */
-		if (*str1 != *str2)
-			return 1;
-		str1++;
-		str2++;
-	}
-
-	return 0;
-}
-
 int rematch(const char *re, const char *match, int cflags)
 {
 	regex_t preg;
@@ -309,28 +289,6 @@ static char *remove_extra_space(char *str)
 	return str;
 }
 
-static char *pkg_name(const char *const_name);
-static char *pkg_name(const char *const_name) {
-	static char name[_POSIX_PATH_MAX];
-	char *ptr;
-	if (!const_name)
-		return NULL;
-	strncpy(name, const_name, sizeof(name));
-	if ((ptr = strrchr(name, ':')) != NULL)
-		*ptr = 0;
-	return name;
-}
-
-static char *slot_name(const char *name);
-static char *slot_name(const char *name) {
-	char *ptr;
-	if (!name)
-		return NULL;
-	if ((ptr = strrchr(name, ':')) != NULL)
-		return ptr+1;
-	return NULL;
-}
-
 static void freeargv(int argc, char **argv)
 {
 	while (argc--)
@@ -623,25 +581,30 @@ _q_static void read_portage_env_file(const char *configroot, const char *file, e
 					abuf = NULL;
 					while (getline(&abuf, &abuflen, fp) != -1) {
 						buf = xrealloc(buf, buflen + abuflen);
+						endq = strchr(abuf, q);
+						if (endq)
+							*endq = '\0';
+
 						strcat(buf, abuf);
 						buflen += abuflen;
 
-						endq = strchr(abuf, q);
-						if (endq) {
-							*endq = '\0';
+						if (endq)
 							break;
-						}
 					}
 					free(abuf);
 
 					if (!endq)
 						warn("%s:%zu: %s: quote mismatch", file, line, vars[i].name);
 
-					s = buf + vars[i].name_len + 1;
+					s = buf + vars[i].name_len + 2;
 				} else {
 					*endq = '\0';
 					++s;
 				}
+			} else {
+				/* no quotes, so chop the spacing/comments ourselves */
+				size_t off = strcspn(s, "# \t\n");
+				s[off] = '\0';
 			}
 
 			set_portage_env_var(&vars[i], s);
@@ -795,7 +758,7 @@ void initialize_portage_env(void)
 				break;
 			}
 
-			var_len = svar - *var->value.s + 1;
+			var_len = svar - s + 1 + (brace ? 2 : 0);
 
 			byte = *svar;
 			*svar = '\0';
@@ -951,7 +914,7 @@ const char *initialize_flat(int cache_type)
 		if (!S_ISDIR(st.st_mode))
 			continue;
 		if (strchr(category[i]->d_name, '-') == NULL)
-			if ((strncmp(category[i]->d_name, "virtual", 7)) != 0)
+			if (strncmp(category[i]->d_name, "virtual", 7) != 0)
 				continue;
 
 		if ((b = scandir(category[i]->d_name, &pn, q_vdb_filter_pkg, alphasort)) < 0)
@@ -1359,7 +1322,7 @@ int main(int argc, char **argv)
 #if 1
 	if (fstat(fileno(stdout), &st) != -1)
 		if (!isatty(fileno(stdout)))
-			if ((S_ISFIFO(st.st_mode)) == 0)
+			if (S_ISFIFO(st.st_mode) == 0)
 				no_colors();
 #endif
 	if ((getenv("TERM") == NULL) || (strcmp(getenv("TERM"), "dumb") == 0))
